pub struct CreateStoreResponse {
pub id: String,
pub name: String,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
}Fields
id: Stringname: Stringcreated_at: Option<Timestamp>updated_at: Option<Timestamp>Trait Implementations
Sourceimpl Clone for CreateStoreResponse
impl Clone for CreateStoreResponse
Sourcefn clone(&self) -> CreateStoreResponse
fn clone(&self) -> CreateStoreResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateStoreResponse
impl Debug for CreateStoreResponse
Sourceimpl Default for CreateStoreResponse
impl Default for CreateStoreResponse
Sourceimpl<'de> Deserialize<'de> for CreateStoreResponse
impl<'de> Deserialize<'de> for CreateStoreResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for CreateStoreResponse
impl Message for CreateStoreResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl MessageSerde for CreateStoreResponse
impl MessageSerde for CreateStoreResponse
Sourcefn package_name(&self) -> &'static str
fn package_name(&self) -> &'static str
package name as in proto file
Sourcefn message_name(&self) -> &'static str
fn message_name(&self) -> &'static str
message name as in proto file
Sourcefn type_url(&self) -> &'static str
fn type_url(&self) -> &'static str
the message proto type url e.g. type.googleapis.com/my.package.MyMessage
Sourcefn new_instance(
&self,
data: Vec<u8>,
) -> Result<Box<dyn MessageSerde>, DecodeError>
fn new_instance( &self, data: Vec<u8>, ) -> Result<Box<dyn MessageSerde>, DecodeError>
Creates a new instance of this message using the protobuf encoded data
Sourcefn try_encoded(&self) -> Result<Vec<u8>, EncodeError>
fn try_encoded(&self) -> Result<Vec<u8>, EncodeError>
Returns the encoded protobuf message as bytes
Sourceimpl Name for CreateStoreResponse
impl Name for CreateStoreResponse
Sourceconst PACKAGE: &'static str = "openfga.v1"
const PACKAGE: &'static str = "openfga.v1"
Package name this message type is contained in. They are domain-like
and delimited by
., e.g. google.protobuf.Sourceconst NAME: &'static str = "CreateStoreResponse"
const NAME: &'static str = "CreateStoreResponse"
Simple name for this
Message.
This name is the same as it appears in the source .proto file, e.g. FooBar.Sourcefn type_url() -> String
fn type_url() -> String
Type URL for this
Message, which by default is the full name with a
leading slash, but may also include a leading domain name, e.g.
type.googleapis.com/google.profile.Person.
This can be used when serializing with the [Any] type.Sourcefn full_name() -> String
fn full_name() -> String
Fully-qualified unique name for this
Message.
It’s prefixed with the package name and names of any parent messages,
e.g. google.rpc.BadRequest.FieldViolation.
By default, this is the package name followed by the message name.
Fully-qualified names must be unique within a domain of Type URLs.Sourceimpl PartialEq for CreateStoreResponse
impl PartialEq for CreateStoreResponse
Sourcefn eq(&self, other: &CreateStoreResponse) -> bool
fn eq(&self, other: &CreateStoreResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CreateStoreResponse
impl Serialize for CreateStoreResponse
impl StructuralPartialEq for CreateStoreResponse